@@ -12,7 +12,7 @@ from .track import Track
 
 class Album:
 
-    def __init__(self, album_url, debugging: bool = False):
+    def __init__(self, album_url, debugging: bool = False, skip_track_scrape: bool = False):
         self.album_title = ""
         self.artist_title = ""
         self.tracks = []
@@ -77,12 +77,19 @@ class Album:
         else:
             self.artist_url = page_json['url'].rpartition('/album')[0]
 
-        for trackjson in page_json['trackinfo']:
-            try:
-                track = Track(str(self.artist_url + trackjson['title_link']))
-                self.tracks.append(track)
-            except:
-                pass
+        if skip_track_scrape == False:
+            for trackjson in page_json['trackinfo']:
+                try:
+                    track = Track(str(self.artist_url + trackjson['title_link']))
+                    self.tracks.append(track)
+                except:
+                    pass
+        else: 
+            for trackjson in page_json['trackinfo']:
+                try:
+                    self.tracks.append(str(self.artist_url + trackjson['title_link']))
+                except:
+                    pass
 
         self.all_songs_available = self.are_all_songs_available(page_json['trackinfo'])
 
@@ -109,8 +116,11 @@ class Album:
         except:
             self.date_published = 0
 
-        self.price['amount'] = float(page_json["current"]["minimum_price"])
-        self.price['currency'] = page_json['albumRelease'][0]['offers']['priceCurrency']
+        try:
+            self.price['amount'] = float(page_json["current"]["minimum_price"])
+            self.price['currency'] = page_json['albumRelease'][0]['offers']['priceCurrency']
+        except:
+            self.price = None
 
         try:
             self.preorder = bool(page_json['album_is_preorder'])
